@@ -14,6 +14,7 @@ from . import cli
 from .config import pass_config
 from .config import Config
 
+
 def get_sources(ctx, args, incomplete):
     config = Config()
     keys = config.sources.keys()
@@ -27,44 +28,48 @@ def get_sources(ctx, args, incomplete):
 def fetch(config):
     pass
 
-def _get_files(config, shell):
-    files = list(filter(bool, shell(["ls", "-tr", config['path']])))
+
+def _get_files(config, shell, verbose=False):
+    regex = config.get("regex", config.get("match", ".*"))
+    if verbose:
+        click.secho(f"Using regex '{regex}' to identify files.", fg="yellow")
+    files = list(filter(bool, shell(["ls", "-tr", config["path"]])))
     for file in files:
-        if re.findall(config.get('regex', '.*'), file):
+        if re.findall(regex, file):
             yield file
 
+
 def transfer(config, filename):
-    destination = os.path.expanduser(config['destination'])
-    subprocess.run([
-        "rsync",
-        f"{config['host']}:{config['path']}/{filename}",
-        destination,
-        "-arP"
-    ])
+    destination = os.path.expanduser(config["destination"])
+    subprocess.run(
+        ["rsync", f"{config['host']}:{config['path']}/{filename}", destination, "-arP"]
+    )
+
 
 @cli.command(help="Choose specific file to download")
-@click.argument('source', required=True, autocompletion=get_sources)
+@click.argument("source", required=True, autocompletion=get_sources)
 @pass_config
 def choose(config, source):
     config.source = source
     with config.shell() as (config, shell):
         files = list(_get_files(config, shell))
-        answer = inquirer.prompt([
-            inquirer.List('file', "Please choose:", choices=list(reversed(files)))
-        ])
+        answer = inquirer.prompt(
+            [inquirer.List("file", "Please choose:", choices=list(reversed(files)))]
+        )
         if not answer:
             sys.exit(0)
-        file = answer['file']
+        file = answer["file"]
         transfer(config, file)
 
+
 @cli.command()
-@click.option('-s', '--source', required=True)
-@click.option('-f', '--filename', required=True)
-@click.option('-H', '--host', required=True)
-@click.option('-U', '--username', required=False)
-@click.option('-r', '--regex', required=True, default=".*")
-@click.option('-p', '--path', required=True)
-@click.option('-d', '--destination', required=True)
+@click.option("-s", "--source", required=True)
+@click.option("-f", "--filename", required=True)
+@click.option("-H", "--host", required=True)
+@click.option("-U", "--username", required=False)
+@click.option("-r", "--regex", required=True, default=".*")
+@click.option("-p", "--path", required=True)
+@click.option("-d", "--destination", required=True)
 @pass_config
 def add(config, source, filename, host, username, regex, path, destination):
     config.source = source
@@ -75,22 +80,39 @@ def add(config, source, filename, host, username, regex, path, destination):
         path=path,
         regex=regex,
         destination=destination,
-        )
-    click.secho("Added host.", fg='green')
+    )
+    click.secho("Added host.", fg="green")
+
 
 @cli.command()
-
 @pass_config
-@click.argument('source', required=True, autocompletion=get_sources)
-def fetch(config, source):
+@click.argument("source", required=True, autocompletion=get_sources)
+@click.option("-n", "--dryrun", is_flag=True)
+@click.option("-v", "--verbose", is_flag=True)
+def fetch(config, source, dryrun, verbose):
     config.source = source
     with config.shell() as (config, shell):
-        files = list(_get_files(config, shell))
+        files = list(_get_files(config, shell, verbose=verbose))
         if not files:
             click.secho("No files found.")
             sys.exit(1)
         file = files[-1]
-        transfer(config, file)
+        if dryrun:
+            click.secho(f"File {file} would be downloaded.", fg="green")
+        else:
+            transfer(config, file)
+
+
+@cli.command()
+def sample():
+    click.secho((
+        "[name1]\n"
+        "regex = *.dump.gz\n"
+        "path = <remote path>\n"
+        "host = <ssh host>\n"
+        "destination = <here to put - a filename>\n"
+    ))
+
 
 @cli.command()
 @click.option(
@@ -113,12 +135,10 @@ def completion(execute):
         ):
             content += [f"\n{line}"]
             click.secho(
-                f"Inserted successfully\n{line}"
-                "\n\nPlease restart you shell."
-                )
-            rc_file.write_text('\n'.join(content))
+                f"Inserted successfully\n{line}" "\n\nPlease restart you shell."
+            )
+            rc_file.write_text("\n".join(content))
         else:
             click.secho("Nothing done - already existed.")
 
-
-    click.secho("\n\n" f"Insert into {rc_file}\n\n" f"echo 'line' >> {rc_file}" "\n\n")
\ No newline at end of file
+    click.secho("\n\n" f"Insert into {rc_file}\n\n" f"echo 'line' >> {rc_file}" "\n\n")
